@@ -21,8 +21,6 @@ class BasePo(object):
     def __init__(self, page: Page, url: str):
         self.url = url
         self.__page = page
-        if self.is_current_page() is False:
-            raise ValueError("page参数值无效")
 
     def get_page(self) -> Page:
         return self.__page
